Client

Struct Client 

pub struct Client { /* private fields */ }
A simple 9p client for ad

Implementations

Source

impl Client

pub fn new() -> Result<Self>

Create a new client connected to ad over it’s 9p unix socket

pub fn new_for_pid(pid: &str) -> Result<Self>

Create a new client connected to the ad session with the given pid over it’s 9p unix socket.

When running under ad, the Client::new method will automatically find and connect to it’s parent session.

pub fn log_events( &mut self, ) -> Result<impl Iterator<Item = Result<LogEvent>> + use<>>

Iterate over the log events emitted by ad

pub fn current_buffer(&mut self) -> Result<String>

Get the currently active buffer id.

pub fn read_dot(&mut self, buffer: &str) -> Result<String>

Read the contents of the dot of the given buffer

pub fn read_body(&mut self, buffer: &str) -> Result<String>

Read the body of the given buffer.

pub fn read_addr(&mut self, buffer: &str) -> Result<String>

Read the current dot address of the given buffer.

pub fn read_filename(&mut self, buffer: &str) -> Result<String>

Read the filename of the given buffer

pub fn read_xaddr(&mut self, buffer: &str) -> Result<String>

Read the x-address of the given buffer.

This is only used by the filesystem interface of ad and will not affect the current editor state.

pub fn read_xdot(&mut self, buffer: &str) -> Result<String>

Read the x-dot of the given buffer.

This is only used by the filesystem interface of ad and will not affect the current editor state.

pub fn write_dot(&mut self, buffer: &str, content: &str) -> Result<usize>

Replace the dot of the given buffer with the provided string.

pub fn append_to_body(&mut self, buffer: &str, content: &str) -> Result<usize>

Append the provided string to the given buffer.

pub fn write_addr(&mut self, buffer: &str, addr: &str) -> Result<usize>

Set the addr of the given buffer.

pub fn write_xdot(&mut self, buffer: &str, content: &str) -> Result<usize>

Replace the xdot of the given buffer with the provided string.

pub fn write_xaddr(&mut self, buffer: &str, content: &str) -> Result<usize>

Set the xaddr of the given buffer.

pub fn ctl(&mut self, command: &str, args: &str) -> Result<()>

Send a control message to ad.

pub fn echo(&mut self, msg: impl AsRef<str>) -> Result<()>

Echo a string message in the status line.

pub fn open(&mut self, path: impl AsRef<str>) -> Result<()>

Open the requested file.

pub fn open_in_new_window(&mut self, path: impl AsRef<str>) -> Result<()>

Open the requested file in a new window.

pub fn reload_current_buffer(&mut self) -> Result<()>

Reload the currently active buffer.

pub fn run_event_filter<F>(&mut self, buffer: &str, filter: F) -> Result<()>
where F: EventFilter,

Run a provided EventFilter until it exits or errors

pub fn body_writer(&self, bufid: &str) -> Result<BodyWriter>

Create a Write impl that can be used to continuously write to the given path